kubernetestest

package
v0.24.82 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0, MIT Imports: 20 Imported by: 0

Documentation

Overview

Package kubernetestest provides infrastructure to support kubernetes related golden files test that are served by an API server.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FixturesToTest

func FixturesToTest(t *testing.T, dirs ...string)

func NewAPI

func NewAPI(o TestAPIOptions, specs ...io.Reader) (*api, error)

Types

type TestAPIOptions

type TestAPIOptions struct {
	FailOn             []string `yaml:"failOn"`
	FindNot            []string `yaml:"findNot"`
	DisableRouteGroups bool     `yaml:"disableRouteGroups"`
}

Jump to